const util = require('util');
const fs = require('fs');
let iz2;
const iz = require('../lib/iz.js');

const assert = require('assert');

describe('IZ global Prototypes:', function () {

	it('loaded copies of iz are not the same object', function() {
		fs.linkSync(__dirname + '/../lib/iz.js', __dirname + '/iz2.js');
		iz2 = require('./iz2.js');
		fs.unlinkSync(__dirname + '/iz2.js');
		//console.log("Survey Says: " + iz === iz2 );
		assert.notStrictEqual(iz, iz2);
	});

	it("Global IZ still knows about its modules", function() {
		iz.Make_Prototypes_Global();
		var evil = iz.Module('Animals.EvilDuck');

		assert.ok(typeof evil === 'function');
	});

	it("non-Global IZ still doesn't know about global modules", function() {
		var failed = false;
		try {
			iz2.Module('Animals.EvilDuck');
		} catch (e) {
			failed = true;
		};
		assert.ok(failed);
	});

	it("Making non-global iz global allows it to see other global iz", function() {
		iz2.Make_Prototypes_Global(true);
		var evil = iz2.Module('Animals.EvilDuck');
		// JAYK
// 		var Animals = iz2.expose('Animals');

		assert.ok(typeof evil === 'function');

	});

	it("non-global iz made global exposes its previously loaded modules", function() {
		var good = iz.Module('Animals.GoodDuck');
		assert.ok(typeof good === 'function');
	});

	it("making Global iz private loses access to global module list", function() {
		iz2.Make_Prototypes_Global(false);
		var failed = false;
		try {
			iz2.Module('Animals.EvilDuck');
		} catch (e) {
			failed = true;
		};
		assert.ok(failed);
	});

	it("making Global iz private loses access to it's original module list", function() {
		iz2.Make_Prototypes_Global(false);
		var failed = false;
		try {
			iz2.Module('Animals.GoodDuck');
		} catch (e) {
			failed = true;
		};
		assert.ok(failed);
	});	

	it("re-privated iz can load modules", function() {
		iz2.Use('Animals.GoodDuck');
		var good = iz2.Module('Animals.GoodDuck');
		assert.ok(typeof good === 'function');

	});	

});
